@@ -582,19 +582,32 @@ def test_DelayedArray_subset():
     y = numpy.random.rand(*test_shape)
     x = delayedarray.DelayedArray(y)
 
-    sub = x[slice(1, 10), [20, 30, 40], [10, 11, 12, 13]]
+    sub = x[numpy.ix_(range(1, 10), [20, 30, 40], [10, 11, 12, 13])]
     assert sub.shape == (9, 3, 4)
     assert isinstance(sub.seed.seed, numpy.ndarray)
     assert len(sub.seed.subset) == 3
     assert (
-        numpy.array(sub)
-        == numpy.array(x)[numpy.ix_(range(1, 10), [20, 30, 40], [10, 11, 12, 13])]
+        numpy.array(sub) == y[numpy.ix_(range(1, 10), [20, 30, 40], [10, 11, 12, 13])]
     ).all()
 
     sub = x[:, :, range(0, 20, 2)]
     assert sub.shape == (30, 55, 10)
     assert isinstance(sub._seed, delayedarray.Subset)
-    assert (numpy.array(sub) == numpy.array(x)[:, :, range(0, 20, 2)]).all()
+    assert (numpy.array(sub) == y[:, :, range(0, 20, 2)]).all()
+
+    booled = [False] * test_shape[-1]
+    booled[2] = True
+    booled[3] = True
+    booled[5] = True
+    sub = x[:, :, booled]
+    assert sub.shape == (30, 55, 3)
+    assert (sub.seed.subset[-1] == numpy.array([2, 3, 5])).all()
+    assert (numpy.array(sub) == y[:, :, booled]).all()
+
+
+#    # Trying vectorized index.
+#    stuff = x[[1,2,3],[4,5,6],[7,8,9]]
+#    assert stuff.shape == (3,)
 
 
 def test_DelayedArray_combine():
